@@ -125,8 +125,9 @@ couchdb_design_document_add_view (CouchdbDesignDocument *document,
 	if (json_object != NULL) {
 		JsonObject *json_views, *this_view;
 
-		json_views = json_object_get_object_member (json_object, "views");
-		if (json_views == NULL) {
+		if (json_object_has_member (json_object, "views"))
+			json_views = json_object_get_object_member (json_object, "views");
+		else {
 			json_views = json_object_new ();
 			json_object_set_object_member (json_object, "views", json_views);
 		}
