@@ -69,7 +69,7 @@ couchdb_document_set_property (GObject *object,
 	case PROP_DATABASE:
 		if (document->priv->database != NULL)
 			g_object_unref (G_OBJECT (document->priv->database));
-		document->priv->database = g_object_ref (G_OBJECT (g_value_get_object (value)));
+		document->priv->database = g_value_dup_object (value);
 		break;
 	default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -583,35 +583,31 @@ couchdb_document_set_struct_field (CouchdbDocument *document, const char *field,
 }
 
 /**
- * couchdb_document_foreach_attachment:
+ * couchdb_document_list_attachments:
  * @document: A #CouchdbDocument object
- * @func: Callback function to be called for each attachment found
- * @user_data: Data to pass to callback function
  *
  * List all the attachments for the given document.
+ *
+ * Return value: A list containing the IDs of all the attachments for the
+ * given document. When no longer needed, the list should
+ * be freed by calling #g_slist_free.
  */
-void
-couchdb_document_foreach_attachment (CouchdbDocument *document,
-				     CouchdbDocumentForeachAttachmentFunc func,
-				     gpointer user_data)
+GSList *
+couchdb_document_list_attachments (CouchdbDocument *document)
 {
+	GSList *list = NULL;
 	CouchdbStructField *attachments;
 
-	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
+	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 
 	attachments = couchdb_document_get_struct_field (document, "_attachments");
 	if (attachments != NULL) {
-		GSList *list;
-
 		list = couchdb_struct_field_get_field_names (attachments);
-		while (list != NULL) {
-			func (document, (const gchar *) list->data, user_data);
-
-			list = g_slist_remove (list, list->data);
-		}
 
 		g_object_unref (G_OBJECT (attachments));
 	}
+
+	return list;
 }
 
 /**
