@@ -193,7 +193,7 @@ couchdb_session_init (CouchdbSession *session)
 	session->priv->credentials = NULL;
 
 #ifdef DEBUG_MESSAGES
-	g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, debug_message, NULL);
+	g_log_set_handler ("Couchdb-GLib", G_LOG_LEVEL_DEBUG, debug_message, NULL);
 #endif
 }
 
@@ -319,6 +319,7 @@ couchdb_session_get_database_info (CouchdbSession *session, const char *dbname,
 		}
 	}
 	g_object_unref (G_OBJECT (parser));
+	g_free (url);
 
 	return result;
 }
@@ -343,8 +344,14 @@ couchdb_session_get_database (CouchdbSession *session, const char *dbname, GErro
 	g_return_val_if_fail (dbname != NULL, NULL);
 
 	dbinfo = couchdb_session_get_database_info (session, dbname, error);
-	if (dbinfo != NULL)
-		return couchdb_database_new (session, dbname);
+	if (dbinfo != NULL) {
+		CouchdbDatabase *db;
+
+		db = couchdb_database_new (session, dbname);
+		couchdb_database_info_unref (dbinfo);
+
+		return db;
+	}
 
 	return NULL;
 }
@@ -454,7 +461,7 @@ couchdb_session_compact_database (CouchdbSession *session, const char *dbname, G
 	url = g_strdup_printf ("%s/%s/_compact", couchdb_session_get_uri (session), dbname);
 	output = json_parser_new ();
 
-	if (couchdb_session_send_message (session, SOUP_METHOD_POST, url, NULL, output, error)) {
+	if (couchdb_session_send_message (session, SOUP_METHOD_POST, url, "", output, error)) {
 		JsonNode *root_node;
 
 		root_node = json_parser_get_root (output);
@@ -562,7 +569,9 @@ _session_authenticate(SoupSession *http_session, SoupMessage *msg,
 
 	if (retrying) {
 		g_signal_emit_by_name (session, COUCHDB_SIGNAL_AUTHENTICATION_FAILED, NULL);
+#ifdef DEBUG_MESSAGES
 		g_debug ("Authentication failed!");
+#endif
 		return FALSE;
 	}
 
@@ -664,7 +673,9 @@ parse_json_response (CouchdbSession *session, JsonParser *json_parser, SoupMessa
 	}
 
 	if (str && str->len > 0) {
+#ifdef DEBUG_MESSAGES
 		g_debug ("Response body: %s", str->str);
+#endif
 		if (!json_parser_load_from_data (json_parser,
 						 (const gchar *) str->str,
 						 str->len,
@@ -726,8 +737,8 @@ couchdb_session_send_message (CouchdbSession *session, const char *method, const
 		}
 	}
 
-	g_debug ("Sending %s to %s... with headers\n: ", method, url);
 #ifdef DEBUG_MESSAGES
+	g_debug ("Sending %s to %s... with headers: ", method, url);
 	soup_message_headers_foreach (http_message->request_headers,
 				      (SoupMessageHeadersForeachFunc) debug_print_headers,
 				      NULL);
@@ -736,10 +747,14 @@ couchdb_session_send_message (CouchdbSession *session, const char *method, const
 	if (SOUP_STATUS_IS_SUCCESSFUL (status)) {
 		if (output != NULL)
 		       	parse_json_response (session, output, http_message, real_error);
+		g_object_unref (G_OBJECT (http_message));
+
 	       	return TRUE;
 	} else {
 		if (error != NULL)
 			g_set_error (error, COUCHDB_ERROR, status, "%s", http_message->reason_phrase);
+		g_object_unref (G_OBJECT (http_message));
+
 		return FALSE;
 	}
 }
@@ -759,7 +774,7 @@ debug_message (const gchar *log_domain, GLogLevelFlags log_level,
 
 	couchdb_env_debug_messages = g_getenv(COUCHDB_ENV_DEBUG_MESSAGES);
 	if (couchdb_env_debug_messages != NULL) {
-		g_print ("couchdb-glib:DEBUG: %s\n", message);
+		g_print ("%s-DEBUG: %s\n", log_domain, message);
 	}
 }
 #endif
